import setuptools

setuptools.setup(
    name="dci_utils",
    version="0.0.572",
    author="Andrew Johnson",
    author_email="andrejohnson@expedia.com",
    description="A set of utilities for DCI jobs",
    url="https://ewegithub.sb.karmalab.net/EWE/dci-data-dci-utils",
    packages=setuptools.find_packages(),
    install_requires=[
    ],
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)
